pub struct TextureAtlas {
pub texture: Handle<Texture>,
pub manifest: AtlasManifest,
/* private fields */
}Expand description
a loaded texture atlas with GPU texture handle and region lookup.
Fields
texture: Handle<Texture>handle to the atlas GPU texture
manifest: AtlasManifestmanifest describing region layout
Implementations
Sourceimpl TextureAtlas
impl TextureAtlas
Sourcepub fn new(texture: Handle<Texture>, manifest: AtlasManifest) -> Self
pub fn new(texture: Handle<Texture>, manifest: AtlasManifest) -> Self
create a new texture atlas from a loaded texture and manifest.
Sourcepub fn region(&self, name: &str) -> &AtlasRegion
pub fn region(&self, name: &str) -> &AtlasRegion
look up a region by name.
returns the AtlasRegion with UV coordinates for this sprite.
Panics
panics if the region does not exist.
Sourcepub fn try_region(&self, name: &str) -> Option<&AtlasRegion>
pub fn try_region(&self, name: &str) -> Option<&AtlasRegion>
look up a region by name, returning None if not found.
Sourcepub const fn texture_handle(&self) -> &Handle<Texture>
pub const fn texture_handle(&self) -> &Handle<Texture>
get the atlas texture handle.
Sourcepub fn region_names(&self) -> impl Iterator<Item = &String>
pub fn region_names(&self) -> impl Iterator<Item = &String>
get all region names.