pub struct RenderTargetId(pub u32);Expand description
opaque identifier for an offscreen render target created by RenderEngine::create_render_target.
store this alongside the returned Handle<Texture> — the handle is used
to draw the target as a sprite; this id is used to direct a camera at the target.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for RenderTargetId
impl Clone for RenderTargetId
Sourcefn clone(&self) -> RenderTargetId
fn clone(&self) -> RenderTargetId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RenderTargetId
Sourceimpl Debug for RenderTargetId
impl Debug for RenderTargetId
impl Eq for RenderTargetId
Sourceimpl Hash for RenderTargetId
impl Hash for RenderTargetId
Sourceimpl PartialEq for RenderTargetId
impl PartialEq for RenderTargetId
Sourcefn eq(&self, other: &RenderTargetId) -> bool
fn eq(&self, other: &RenderTargetId) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Resource for RenderTargetId
impl StructuralPartialEq for RenderTargetId